@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2020 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2021 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -26,28 +26,20 @@ extern "C" {
   Define declarations.
 */
 #define MagickPackageName "ImageMagick"
-#define MagickCopyright  "© 1999-2020 ImageMagick Studio LLC"
+#define MagickCopyright  "(C) 1999-2021 ImageMagick Studio LLC"
 #define MagickLibVersion  0x70A
 #define MagickLibVersionText  "7.0.10"
-#define MagickLibVersionNumber  7,0,0
-#define MagickLibAddendum  "-27"
-#define MagickLibInterface  7
-#define MagickLibMinInterface  7
-#if defined(_WINDOWS)
-#  if defined(_WIN64)
-#    define MagickPlatform "x64"
-#  else
-#    define MagickPlatform "x86"
-#  endif
-#else
-#define MagickPlatform  "i686"
-#endif
+#define MagickLibVersionNumber  9,0,0
+#define MagickLibAddendum  "-61"
+#define MagickLibInterface  9
+#define MagickLibMinInterface  9
+#define MagickPlatform  "x86_64"
 #define MagickppLibVersionText  "7.0.10"
 #define MagickppLibVersionNumber  4:0:0
-#define MagickppLibAddendum  "-27"
+#define MagickppLibAddendum  "-61"
 #define MagickppLibInterface  4
 #define MagickppLibMinInterface  4
-#define MagickReleaseDate  "2021-02-07"
+#define MagickReleaseDate  "2023-05-13"
 #define MagickAuthoritativeLicense  \
   "https://imagemagick.org/script/license.php"
 #define MagickAuthoritativeURL  "https://imagemagick.org"
